@@ -2,11 +2,11 @@
 
 __author__ = """Sebastian Weigand"""
 __email__ = "s.weigand.phy@gmail.com"
-__version__ = "0.2.6"
+__version__ = "0.2.7"
 
 import flake8
 
-from .flake8_integration.formatter import IpynbFormatter
+from flake8_nb.flake8_integration.formatter import IpynbFormatter
 
 __all__ = [
     IpynbFormatter.__name__,
