@@ -1,16 +1,15 @@
-# -*- coding: utf-8 -*-
-
 """Command-line implementation of flake8_nb."""
 import sys
-from typing import List, Optional
+from typing import List
+from typing import Optional
 
 from flake8_nb import FLAKE8_VERSION_TUPLE
 from flake8_nb.flake8_integration.cli import Flake8NbApplication
 
 
 def main(argv: Optional[List[str]] = None) -> None:
-    """
-    Execute the main bit of the application.
+    """Execute the main bit of the application.
+
     This handles the creation of an instance of :class:`Application`, runs it,
     and then exits the application.
 
@@ -30,5 +29,5 @@ def main(argv: Optional[List[str]] = None) -> None:
             argv = argv[1:]
 
     app = Flake8NbApplication()
-    app.run(argv)
+    app.run(argv)  # type: ignore
     app.exit()
