@@ -11,8 +11,8 @@ from typing import Union
 from flake8.formatting.default import Default
 from flake8.style_guide import Violation
 
-from ..parsers.notebook_parsers import NotebookParser
-from ..parsers.notebook_parsers import map_intermediate_to_input
+from flake8_nb.parsers.notebook_parsers import NotebookParser
+from flake8_nb.parsers.notebook_parsers import map_intermediate_to_input
 
 
 def map_notebook_error(violation: Violation) -> Union[Tuple[str, int], None]:
