@@ -6,8 +6,7 @@ import pytest
 from flake8_nb.__main__ import main
 from flake8_nb.parsers.notebook_parsers import InvalidNotebookWarning
 from flake8_nb.parsers.notebook_parsers import NotebookParser
-
-from . import TEST_NOTEBOOK_BASE_PATH
+from tests import TEST_NOTEBOOK_BASE_PATH
 
 
 @pytest.mark.parametrize("keep_intermediate", [True, False])
